pyexcel.Sheet
=============

.. currentmodule:: pyexcel

.. autoclass:: Sheet

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Sheet.__init__
      ~Sheet.cell_value
      ~Sheet.clone
      ~Sheet.column_at
      ~Sheet.column_range
      ~Sheet.columns
      ~Sheet.contains
      ~Sheet.cut
      ~Sheet.delete_columns
      ~Sheet.delete_named_column_at
      ~Sheet.delete_named_row_at
      ~Sheet.delete_rows
      ~Sheet.enumerate
      ~Sheet.extend_columns
      ~Sheet.extend_columns_with_rows
      ~Sheet.extend_rows
      ~Sheet.filter
      ~Sheet.format
      ~Sheet.get_array
      ~Sheet.get_bookdict
      ~Sheet.get_csv
      ~Sheet.get_csvz
      ~Sheet.get_dict
      ~Sheet.get_fods
      ~Sheet.get_grid
      ~Sheet.get_handsontable
      ~Sheet.get_handsontable_html
      ~Sheet.get_html
      ~Sheet.get_internal_array
      ~Sheet.get_json
      ~Sheet.get_latex
      ~Sheet.get_latex_booktabs
      ~Sheet.get_mediawiki
      ~Sheet.get_ndjson
      ~Sheet.get_ods
      ~Sheet.get_orgtbl
      ~Sheet.get_pipe
      ~Sheet.get_plain
      ~Sheet.get_records
      ~Sheet.get_rst
      ~Sheet.get_simple
      ~Sheet.get_svg
      ~Sheet.get_texttable
      ~Sheet.get_tsv
      ~Sheet.get_tsvz
      ~Sheet.get_url
      ~Sheet.get_xls
      ~Sheet.get_xlsm
      ~Sheet.get_xlsx
      ~Sheet.group_rows_by_column
      ~Sheet.init
      ~Sheet.map
      ~Sheet.name_columns_by_row
      ~Sheet.name_rows_by_column
      ~Sheet.named_column_at
      ~Sheet.named_columns
      ~Sheet.named_row_at
      ~Sheet.named_rows
      ~Sheet.number_of_columns
      ~Sheet.number_of_rows
      ~Sheet.paste
      ~Sheet.plot
      ~Sheet.project
      ~Sheet.rcolumns
      ~Sheet.region
      ~Sheet.register_input
      ~Sheet.register_io
      ~Sheet.register_presentation
      ~Sheet.reverse
      ~Sheet.row_at
      ~Sheet.row_range
      ~Sheet.rows
      ~Sheet.rrows
      ~Sheet.rvertical
      ~Sheet.save_as
      ~Sheet.save_to_database
      ~Sheet.save_to_django_model
      ~Sheet.save_to_memory
      ~Sheet.set_array
      ~Sheet.set_bookdict
      ~Sheet.set_column_at
      ~Sheet.set_csv
      ~Sheet.set_csvz
      ~Sheet.set_dict
      ~Sheet.set_fods
      ~Sheet.set_grid
      ~Sheet.set_handsontable
      ~Sheet.set_handsontable_html
      ~Sheet.set_html
      ~Sheet.set_json
      ~Sheet.set_latex
      ~Sheet.set_latex_booktabs
      ~Sheet.set_mediawiki
      ~Sheet.set_named_column_at
      ~Sheet.set_named_row_at
      ~Sheet.set_ndjson
      ~Sheet.set_ods
      ~Sheet.set_orgtbl
      ~Sheet.set_pipe
      ~Sheet.set_plain
      ~Sheet.set_records
      ~Sheet.set_row_at
      ~Sheet.set_rst
      ~Sheet.set_simple
      ~Sheet.set_svg
      ~Sheet.set_texttable
      ~Sheet.set_tsv
      ~Sheet.set_tsvz
      ~Sheet.set_url
      ~Sheet.set_xls
      ~Sheet.set_xlsm
      ~Sheet.set_xlsx
      ~Sheet.to_array
      ~Sheet.to_dict
      ~Sheet.to_records
      ~Sheet.top
      ~Sheet.top_left
      ~Sheet.transpose
      ~Sheet.vertical
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Sheet.array
      ~Sheet.bookdict
      ~Sheet.colnames
      ~Sheet.content
      ~Sheet.csv
      ~Sheet.csvz
      ~Sheet.dict
      ~Sheet.fods
      ~Sheet.grid
      ~Sheet.handsontable
      ~Sheet.handsontable_html
      ~Sheet.html
      ~Sheet.json
      ~Sheet.latex
      ~Sheet.latex_booktabs
      ~Sheet.mediawiki
      ~Sheet.ndjson
      ~Sheet.ods
      ~Sheet.orgtbl
      ~Sheet.pipe
      ~Sheet.plain
      ~Sheet.records
      ~Sheet.rownames
      ~Sheet.rst
      ~Sheet.simple
      ~Sheet.stream
      ~Sheet.svg
      ~Sheet.texttable
      ~Sheet.tsv
      ~Sheet.tsvz
      ~Sheet.url
      ~Sheet.xls
      ~Sheet.xlsm
      ~Sheet.xlsx
   
   